/*
 * Copyright (C) 2016 Texas Instruments Incorporated - http://www.ti.com/
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/

//******************************************************************************
// Version history:
// 1.0 07/17             Initial version. (Nima Eskandari)
// 1.1 07/17             Added Comments. (Nima Eskandari)
//----------------------------------------------------------------------------
//   Designed 2017 by Texas Instruments
//
//   Nima Eskandari
//   Texas Instruments Inc.
//   August 2017
//   Built with CCS Version: Code Composer Studio v7
//******************************************************************************

#include <stdint.h>
#include <stdio.h>
#include <string.h>
#include <stddef.h>
#include <uart_if.h>
#include <config.h>
#include <Board.h>
#include <utils.h>

#include <ti/drivers/UART.h>

UART_Handle debug_uart;
UART_Params debug_uartParams;

//*****************************************************************************
// Initialize UART ************************************************************
// Opens the serial port (UART communication) *********************************
//*****************************************************************************
void Debug_UART_Initialize()
{
    /* Create a UART with data processing off. */
    UART_Params_init(&debug_uartParams);
    debug_uartParams.writeDataMode = UART_DATA_BINARY;
    debug_uartParams.readDataMode = UART_DATA_BINARY;
    debug_uartParams.readReturnMode = UART_RETURN_FULL;
    debug_uartParams.readEcho = UART_ECHO_OFF;
    debug_uartParams.baudRate = 9600;


    debug_uart = UART_open(Board_UART0, &debug_uartParams);

    if (debug_uart == NULL) {
        /* UART_open() failed */
        while (1);
    }
}

void Debug_UART_printString(char* array)
{
    UART_write(debug_uart, array, strlen(array));
}

void Debug_UART_printStringWithNumber(char* format, uint32_t value)
{
    char str[80];
    sprintf(str, format, value);
    Debug_UART_printString(str);
}

